'''Apport package hook for the ubiquity live CD installer.

Copyright (C) 2009 Canonical Ltd.
Authors: Colin Watson <cjwatson@ubuntu.com>,
         Brian Murray <brian@ubuntu.com>'''

import os.path
import apport.hookutils

def add_installation_log(report, ident, name):
    if os.path.exists('/var/log/installer/%s' % name):
        f = '/var/log/installer/%s' % name
    elif os.path.exists('/var/log/%s' % name):
        f = '/var/log/%s' % name
    else:
        return

    if os.access(f, os.R_OK):
        report[ident] = (f,)
    else:
        apport.hookutils.attach_root_command_outputs(report,
            {ident: "cat '%s'" % f})

def add_info(report, ui):
    add_installation_log(report, 'UbiquitySyslog', 'syslog')
    if 'SQUASHFS error: Unable to read' in report['UbiquitySyslog']:
        ui.information("The system log from your installation contains an error.  The specific error commonly occurs when there is an issue with the media from which you were installing.  This can happen when your media is dirty or damaged or when you've burned the media at a high speed.  Please try cleaning the media and or burning new media at a lower speed.  In the event that you continue to encounter these errors it may be an issue with your CD / DVD drive.")
        raise StopIteration
    add_installation_log(report, 'UbiquityPartman', 'partman')
    if os.path.exists('/var/log/installer/debug'):
        response = ui.yesno("The debug log file from your installation would help us a lot but includes the password you used for your user when installing Ubuntu.  Do you want to include this log file?")
        if response is None:
            raise StopIteration
        if response:
            add_installation_log(report, 'UbiquityDebug', 'debug')
    if os.path.exists('/var/log/installer/dm'):
        report['UbiquityDm'] = ('/var/log/installer/dm',)
    add_installation_log(report, 'Casper', 'casper.log')
    if os.path.exists('/var/log/oem-config.log'):
        report['OemConfigLog'] = ('/var/log/oem-config.log',)
